"""JetRacer ROS 2 launch

This file contains the ROS 2 launch description for a JetRacer.
"""

from launch import LaunchDescription
from launch.actions import IncludeLaunchDescription
from launch.launch_description_sources import PythonLaunchDescriptionSource
from launch.substitutions import PathJoinSubstitution
from launch_ros.substitutions import FindPackageShare


def generate_launch_description() -> LaunchDescription:
    """
    Generate a launch description for the jetracerros2 package
    launching both the movement controllers and the lidar node.

    :return: The launch description.
    :rtype: LaunchDescription
    """

    lidar_launch = IncludeLaunchDescription(
        PythonLaunchDescriptionSource([
            PathJoinSubstitution([
                FindPackageShare('jetracerros2'), 'launch', 'lidar_launch.py'
            ])
        ])
    )

    movement_controller_launch = IncludeLaunchDescription(
        PythonLaunchDescriptionSource([
            PathJoinSubstitution([
                FindPackageShare('jetracerros2'), 'launch', 'movement_controller_launch.py'
            ])
        ])
    )

    return LaunchDescription([
        movement_controller_launch,
        lidar_launch,
    ])
