"""Lidar launch

This file contains the ROS 2 launch description for the Lidar system.
"""

from launch import LaunchDescription
from launch_ros.actions import Node


def generate_launch_description() -> LaunchDescription:
    """
    Generate a launch description for the rplidar_ros package.
    Launches the rplidar_node for the RPLidar A1.
    Also launches the laser_filter node from the jetracerros2 package
    to filter the laser scan data.

    :return: The launch description.
    :rtype: LaunchDescription
    """

    return LaunchDescription([
        Node(
            package = 'rplidar_ros',
            executable = 'rplidar_node',
            name = 'rplidar_node',
            parameters = [{'channel_type': 'serial',
                           'serial_port': '/dev/ttyACM1',
                           'serial_baudrate': 115200,
                           'frame_id': 'laser_frame',
                           'inverted': False,
                           'angle_compensate': True}],
            output = 'screen',
            namespace = '/jetracerros2'),
        Node(
            package = 'jetracerros2',
            executable = 'laser_filter',
            namespace = '/jetracerros2',
        ),
    ])
