"""Movement controller launch

This file contains the launch description for all movement controllers of a JetRacer.
"""

from launch import LaunchDescription
from launch_ros.actions import Node


def generate_launch_description() -> LaunchDescription:
    """
    Generate a launch description for the jetracerros2 package launching the movement controllers.
    The launch file will start the following nodes:
    - jetracer_controller :class:`JetracerController`
    - servo_motor_controller :class:`ServoMotorController`

    All nodes will be started in the /jetracerros2 namespace.

    :return: The launch description.
    :rtype: LaunchDescription
    """

    return LaunchDescription([
        Node(
            package = 'jetracerros2',
            executable = 'jetracer_controller',
            namespace = '/jetracerros2'
        ),
        Node(
            package = 'jetracerros2',
            executable = 'servo_motor_controller',
            namespace = '/jetracerros2',
        ),
    ])
