"""Initialize application

This file initializes the flask programm and all other libraries.
"""
import os

import sqlalchemy as sa

from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from flask_migrate import Migrate
from flask_login import LoginManager
from flask_socketio import SocketIO
from flask_cors import CORS

from uppaal2jetracer.webinterface.config import Config
from uppaal2jetracer.webinterface.app.webhandler import WebHandler
from uppaal2jetracer.versioncontrol.versioncontrol import ProjectManager, VersionManager
from uppaal2jetracer.versioncontrol.database import DatabaseConnection

app = Flask(__name__)
app.config.from_object(Config)

db = SQLAlchemy(app)
migrate = Migrate(app, db)

login = LoginManager(app)
login.login_view = 'login'

cors = CORS(app, resources = {r"/*": {"origins": "*"}})

socketio = SocketIO(app, cors_allowed_origins = "*",
                    ping_timeout = app.config.get('SOCKET_TIMOUT_DURATION'),
                    ping_interval = app.config.get('SOCKET_INTERVAL_DURATION'))

db_conn = DatabaseConnection("data" + os.sep + "database")

pm = ProjectManager(db_conn)
vm = VersionManager(db_conn)

webhandler = WebHandler(vm, pm)

from uppaal2jetracer.webinterface.app import routes, models, sockets

with app.app_context():
    g_u = db.session.scalar(sa.select(models.Global).where(
        models.Global.id == app.config.get("GLOBAL_ID")
    ))

    secret_token = app.config.get("SECRET_TOKEN")

    if g_u is None:

        g_u = models.Global(id = app.config.get("GLOBAL_ID"))
        g_u.set_password(secret_token)

        db.session.add(g_u)
        db.session.commit()

    elif not g_u.check_password(secret_token):

        g_u.set_password(secret_token)

        db.session.commit()
