/**
 * This file holds the event for opening the projects frame.
 * 
 * @module scripts/events/main/change
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Opens the projects frame.
 * 
 * @function change_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function change_event(target, args, requestHandler, pageHandler, eventHandler) {
    
    if (pageHandler.getIsFrameLoaded(args)) {

        pageHandler.openProjectsFrame(null);
        eventHandler.isHandlingEvent = false;

        return;

    }

    requestHandler.GET("/api/all", [ "False" ], (res) => {

        if (res.type) {

            pageHandler.openProjectsFrame(res.payload);

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default change_event;
