/**
 * This file holds the event for clearing the console.
 * 
 * @module scripts/events/main/clear
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Clears the console on the page.
 * 
 * @function clear_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function clear_event(target, args, requestHandler, pageHandler, eventHandler) {

    pageHandler.clearConsole();
    eventHandler.isHandlingEvent = false;

}

export default clear_event;
