/**
 * This file holds the event for toggling the debug mode.
 * 
 * @module scripts/events/main/debug
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Toggles the debug mode and the debug slider.
 * 
 * @function debug_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function debug_event(target, args, requestHandler, pageHandler, eventHandler) {

    requestHandler.POST("/api/debug", [], {}, (res) => {

        if (res.type) {

            pageHandler.toggleDebug(args);

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default debug_event;
