/**
 * This file holds the event for parsing and then running a single version.
 * 
 * @module scripts/events/main/parse&run
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Parses and adds a new version, then runs that version.
 * 
 * @function parse_and_run_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function parse_and_run_event(target, args, requestHandler, pageHandler, eventHandler) {

    let parseCallback = eventHandler.events[eventHandler.PARSE_EVENT_TAG];
    parseCallback(target, args, requestHandler, pageHandler, eventHandler, true);

}

export default parse_and_run_event;
