/**
 * This file holds the event for favoriting a version.
 * 
 * @module scripts/events/main/favorite
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Favorites a certain version.
 * 
 * @function favorite_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function favorite_event(target, args, requestHandler, pageHandler, eventHandler) {

    let versionId = pageHandler.getVersionId(target);

    requestHandler.POST("/api/favorite", [ versionId ], {}, (res) => {

        if (res.type) {

            pageHandler.favoriteVersion(res.payload, target);
            pageHandler.addError(res.message, false);

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default favorite_event;
